@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Data::Hive;
 BEGIN {
-  $Data::Hive::VERSION = '1.002';
+  $Data::Hive::VERSION = '1.003';
 }
 # ABSTRACT: convenient access to hierarchical data
 
@@ -95,6 +95,17 @@ sub KEYS {
 }
 
 
+sub COPY_ONTO {
+  my ($self, $target) = @_;
+
+  $target->SET( $self->GET ) if $self->EXISTS;
+
+  for my $key ($self->KEYS) {
+    $self->HIVE($key)->COPY_ONTO( $target->HIVE($key) );
+  }
+}
+
+
 sub ITEM {
   my ($self, @rest) = @_;
   return $self->HIVE(@rest);
@@ -176,7 +187,7 @@ Data::Hive - convenient access to hierarchical data
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 SYNOPSIS
 
@@ -384,6 +395,17 @@ This shows the expected results:
   foo/xyz      | abc, def
   foo/123      |
 
+=head3 COPY_ONTO
+
+  $hive->foo->COPY_ONTO( $another_hive->bar );
+
+This method copies all the existing values found at or under the current path
+to another Data::Hive, using either the same or a different store.
+
+Currently, this will set each found value individually.  In the future, store
+classes should have the ability to receive a bulk-set message to operate in a
+transaction, if appropriate.
+
 =head3 HIVE
 
   $hive->HIVE('foo');          #  equivalent to $hive->foo
